touch_task

Function touch_task 

pub(crate) fn touch_task(
    button: Rp2040Button,
) -> Result<SpawnToken<impl Sized>, SpawnError>
Drive the touch button sampler. Spawn once at boot.

button is a wrapped Input configured with an internal pull-up. The pin is owned by this task for the lifetime of the firmware.